// Heavily inspired by:
// http://stackoverflow.com/questions/2362008/compare-two-images-pixel-by-pixel-in-java-programming

import javax.imageio.ImageIO;
import java.io.File;
import java.awt.image.BufferedImage;

public class CompareImages
{
    public static void main( String[] args ) throws Exception {
        if (args.length == 0) {
            System.out.println( "USAGE: CompareImages image_file1 image_file2" );
            System.exit( 10 );
        }

        File file1 = new File( args[0] );
        File file2 = new File( args[1] );

        BufferedImage image1 = ImageIO.read( file1 );
        BufferedImage image2 = ImageIO.read( file2 );

        int x1 = image1.getWidth();
        int x2 = image2.getWidth();
        if ( x1 != x2 ) {
            System.out.println( "Widths are different: " + x1 + " != " + x2 );
            System.exit( 11 );
        }

        int y1 = image1.getHeight();
        int y2 = image2.getHeight();
        if ( y1 != y2 ) {
            System.out.println( "Heights are different: " + y1 + " != " + y2 );
            System.exit( 12 );
        }

        for ( int x = 0; x < x1; x++ ) {
            for ( int y = 0; y < y1; y++ ){
                int p1 = image1.getRGB( x, y );
                int p2 = image2.getRGB( x, y );
                if ( p1 != p2 ) {
                    System.out.println("Pixel is different at x/y " + x + "/" + y + ": " + p1 + " != " + p2 );
                    System.exit( 13 );
                }
            }
        }

        System.out.println( "Images are identical" );
        System.exit( 0 );
    }
}
